@@ -35,7 +35,7 @@ from calculate.lib.utils.files import (runOsCommand,isMount,removeDir,
 from calculate.lib.utils.common import getTupleVersion,cmpVersion
 from calculate.lib.utils.device import (detectDeviceForPartition, 
                                 getUdevDeviceInfo, countPartitions)
-from calculate.lib.variables.linux import LinuxDataVars
+from calculate.lib.variables.linux import LinuxDataVars,Linux
 from calculate.lib.cl_vars_share import varsShare
 from calculate.lib.cl_template import _terms
 
@@ -132,7 +132,7 @@ class Distributive(object):
             elif "Squashfs filesystem" in ftype:
                 return SquashDistributive(filename)
             elif path.isdir(filename):
-                if path.exists(path.join(filename,"livecd")):
+                if path.isfile(path.join(filename,"livecd")):
                     return IsoDistributive(filename)
                 else:
                     return DirectoryDistributive(filename)
@@ -283,7 +283,7 @@ class Distributive(object):
             raise DistributiveError(_("'%s' not found")%"cp")
         try:
             joinFrom = partial(path.join,fromdir)
-            params = [cpCmd,"-a"]+\
+            params = [cpCmd,"-a","-x"]+\
                      map(joinFrom,
                      ifilterfalse(byfile or operator.not_,
                      listDirectory(fromdir)))+\
@@ -407,17 +407,20 @@ class Distributive(object):
     def getInfoFromDirectory(self,directory):
         d = {}
         if path.lexists(path.join(directory,'lib64')):
-            d['march'] = 'x86_64'
+            d['os_arch_machine'] = 'x86_64'
         elif path.lexists(path.join(directory,'lib')):
-            d['march']= 'i686'
+            d['os_arch_machine']= 'i686'
         else:
-            d['march'] = ''
+            d['os_arch_machine'] = ''
         dv = LinuxDataVars(systemRoot=directory)
-        d["name"] = dv.Get('os_linux_shortname')
-        d['ver'] = dv.Get('os_linux_ver')
-        d['build'] = dv.Get('os_linux_build')
+        d["os_linux_shortname"] = dv.Get('os_linux_shortname')
+        d['os_linux_ver'] = dv.Get('os_linux_ver')
+        d['os_linux_build'] = dv.Get('os_linux_build')
+        d['os_linux_name'] = dv.Get('os_linux_name')
+        d['os_linux_subname'] = dv.Get('os_linux_subname')
+        d['os_linux_system'] = dv.Get('os_linux_system')
         # make lazy call
-        d['filesnum'] = partial(dv.Get,'os_linux_files')
+        d['os_linux_files'] = partial(dv.Get,'os_linux_files')
         return d.copy()
 
     def getInfo(self,filename=None):
@@ -846,7 +849,8 @@ class PartitionDistributive(Distributive):
             return True
         fdiskProg, gdiskProg = checkUtils('/sbin/fdisk','/usr/sbin/gdisk')
         partitionNumber = \
-            getUdevDeviceInfo(name=dev).get('ID_PART_ENTRY_NUMBER','')
+            getUdevDeviceInfo(name=dev).get('ID_PART_ENTRY_NUMBER','') or \
+            getUdevDeviceInfo(name=dev).get('UDISKS_PARTITION_NUMBER','')
         devicePartitionCount = countPartitions(deviceName)
         if deviceName and not partitionNumber:
             raise DistributiveError(
