@@ -18,12 +18,14 @@ import os
 import re
 import sys
 import time
-import traceback
 from os import path
 from StringIO import StringIO
+from random import choice
+import string
 from time import sleep
 from subprocess import PIPE,STDOUT
 from shutil import copy2
+from calculate.core.server.func import safetyWrapper
 from calculate.lib.utils.files import (runOsCommand,pathJoin,scanDirectory,
                                        process,listDirectory,STDOUT,checkUtils)
 from calculate.lib.utils.common import (appendProgramToEnvFile,
@@ -63,12 +65,9 @@ class InstallError(Exception):
 from cl_migrate_users import migrate, currentUsers, MigrationError
 from calculate.lib.encrypt import encrypt
 
-from calculate.lib.cl_lang import setLocalTranslate
+from calculate.lib.cl_lang import setLocalTranslate,getLazyLocalTranslate
 setLocalTranslate('cl_install3',sys.modules[__name__])
-
-class printNoColor:
-    def colorPrint(self,attr,fg,bg,string):
-        sys.stdout.write(string)
+__ = getLazyLocalTranslate(_)
 
 class cltCopy(scanDirectory):
     """Copy clt files
@@ -139,7 +138,6 @@ class Install(color_print):
         # refresh information about device in udevadm info
         refreshUdev()
 
-
     def setNoColor(self):
         self.color = False
 
@@ -152,7 +150,6 @@ class Install(color_print):
         else:
             self.clVars = datavars
 
-
     def canInstallGrub2(self,target):
         """Check that system has grub2 in current and installed system"""
         if self.clVars.Get('os_grub2_path'):
@@ -171,7 +168,7 @@ class Install(color_print):
             else:
                 self.installLegacyGrubBootloader(targetDistr)
 
-    def closeClTemplate(self):
+    def closeClTemplate(self,error=None):
         if self.clTempl:
             if self.clTempl.cltObj:
                 self.clTempl.cltObj.closeFiles()
@@ -196,10 +193,15 @@ class Install(color_print):
 
         self.clTempl = ProgressTemplate(self.setProgress, self.clVars,
                                         cltObj=useClt,
-                                        cltFilter=False)
+                                        cltFilter=False,
+                                        printSUCCESS=self.printSUCCESS,
+                                        printWARNING=self.printWARNING,
+                                        printERROR=self.printERROR)
 
         dirsFiles = self.clTempl.applyTemplates()
         try:
+            if self.clTempl.getWarning():
+                self.printWARNING(self.clTempl.getWarning())
             if self.clTempl.getError():
                 self.printERROR(self.clTempl.getError())
                 return False
@@ -231,7 +233,10 @@ class Install(color_print):
             self.clVars.Get('cl_template_clt_path')))
         self.clVars.Set('cl_template_clt_path',clTemplateCltPath,True)
         self.clTempl = ProgressTemplate(self.setProgress,self.clVars,
-                                        cltFilter=False)
+                                        cltFilter=False,
+                                        printSUCCESS=self.printSUCCESS,
+                                        printWARNING=self.printWARNING,
+                                        printERROR=self.printERROR)
         dirsFiles = self.clTempl.applyTemplates()
         if self.clTempl.getError():
             raise InstallError(self.clTempl.getError())
@@ -340,7 +345,9 @@ class Install(color_print):
         parttable = self.clVars.Select('os_device_table',where='os_device_dev',
                                   eq=disk,limit=1)
         partitionNumber = \
-            getUdevDeviceInfo(name=partition).get('ID_PART_ENTRY_NUMBER','')
+            getUdevDeviceInfo(name=partition).get('ID_PART_ENTRY_NUMBER','') or \
+            getUdevDeviceInfo(name=partition).get('UDISKS_PARTITION_NUMBER','')
+
         devicePartitionCount = countPartitions(deviceName)
         if deviceName and not partitionNumber:
             raise DistributiveError(
@@ -556,119 +563,6 @@ class Install(color_print):
         open(nvidiaMaskFile,'w').write(maskNvidia)
         return True
 
-    def configureSystem(self,autologin):
-        """configuring the current system"""
-        configureMessage = _("Configuring the system")
-        error = None
-        keyInter = None
-        try:
-            try:
-                if autologin:
-                    objUsers = currentUsers()
-                    if not objUsers.hasUsers(autologin):
-                        self.printERROR(_("User %s does not exist")%autologin)
-                    else:
-                        self.setUsers([],autologin)
-                # install this package
-                self.installPackage()
-                self.printMessageForTest(configureMessage)
-                self.printByResult(self.applyTemplatesStartup())
-
-                linuxShortname = self.clVars.Get('os_install_linux_shortname')
-                # install desktop package
-                if linuxShortname in ("CLD","CLS","CLDG","CLDX"):
-                    desktopLib = '/usr/lib/calculate-2.2/calculate-desktop/pym'
-                    if path.exists(desktopLib):
-                        sys.path.insert(0, path.abspath(desktopLib))
-                        from cl_desktop import desktop
-                        self.printMessageForTest(
-                             _("calculate-desktop enabled "
-                               "for package configuration"))
-                        self.hideStdout()
-                        objDesktop = desktop()
-                        objDesktop.createClVars()
-                        res = objDesktop.installProg()
-                        self.showStdout()
-
-                # install client package
-                if linuxShortname in ("CLD","CLDG","CLDX"):
-                    clientLib = '/usr/lib/calculate-2.2/calculate-client/pym'
-                    if path.exists(clientLib):
-                        sys.path.insert(0, path.abspath(clientLib))
-                        from cl_client import client
-                        self.printMessageForTest(
-                         _("calculate-client enabled "
-                           "for package configuration"))
-                        objClient = client()
-                        objClient.createClVars()
-                        self.hideStdout()
-                        if hasattr(objClient,"updateEnvFiles") and \
-                            objClient.updateEnvFiles():
-                            objClient.clVars.flIniFile()
-                        res = objClient.installProg(onlyEnv=True)
-                        self.showStdout()
-                        self.printByResult(res)
-
-                pathGlModules = path.join(self.clVars.Get('cl_chroot_path'),
-                                         'usr/lib/opengl')
-                self.printMessageForTest(_("Checking the video driver"))
-                self.printByResult(self.checkVideoDriver())
-                if path.exists(pathGlModules):
-                    self.printMessageForTest(_("Configuring OpenGL"))
-                    self.printByResult(self.setupOpenGL())
-                # if change video driver, then restore initramfs
-                installDrv = self.clVars.Get('os_install_x11_video_drv')
-                if self.clVars.Get('os_x11_video_drv') != installDrv:
-                    initrdPath = path.join('/boot',
-                                self.clVars.Get('os_install_initrd'))
-                    initrdInstallPath = path.join('/boot',
-                                self.clVars.Get('os_install_initrd_install'))
-                    needMod = {'radeon':'radeon',
-                               'intel':'i915',
-                               'nouveau':'nouveau'}.get(installDrv,'uvesafb')
-                    if not InitRamFs(initrdPath).isModuleInside(needMod):
-                        self.printMessageForTest(_("Restoring initramfs"))
-                        self.printByResult(InitRamFs(initrdInstallPath)\
-                                .cleanInitRamFs(initrdPath))
-                oldXdrv = self.clVars.Get('os_x11_video_drv')
-                newXdrv = self.clVars.Get('os_install_x11_video_drv')
-                if oldXdrv != newXdrv:
-                    kmsDrv = ("radeon","i915","intel","nouveau","ati")
-                    self.defaultPrint("\n")
-                    if oldXdrv in kmsDrv or newXdrv in kmsDrv:
-                        self.defaultPrint(
-                            _("To apply the changes, reboot the system")
-                            +".\n")
-                    else:
-                        self.defaultPrint(
-                            _("To apply the changes, restart the X server")
-                            +".\n")
-            except (InstallError,VariableError,DistributiveError),e:
-                error = e
-            except Exception,e:
-                error = ""
-                for i in apply(traceback.format_exception, sys.exc_info()):
-                    error += i
-            except KeyboardInterrupt:
-                keyInter = True
-        except KeyboardInterrupt:
-            keyInter = True
-        self.showStdout()
-        if keyInter:
-            if self.startMessage:
-                self.printByResult(False)
-            self.defaultPrint("\n")
-            self.printWARNING(_("System configuration interrupted"))
-            error = _("Configuration manually interrupted")
-        if self.startMessage:
-            self.printByResult(False)
-        if error:
-            for line in filter(lambda x: x,str(error).split('\n')):
-                self.printERROR(line)
-            self.printERROR(_("System configuration failed"))
-            return False
-        return True
-
     def cleanInitrd(self):
         """Clean initrd from needless modules"""
         # get path to initrd and initrd-install in new system
@@ -709,6 +603,7 @@ class Install(color_print):
         self.cleanInitrd()
         self.endTask("")
 
+        self.remountNTFS()
         # join templates
         self.startTask(_("Updating the configuration"),progress=True)
         self.applyTemplates(targetDistr.getDirectory(),
@@ -754,293 +649,178 @@ class Install(color_print):
                     _("To apply the changes, restart the X server")
                     +".\n")
 
-    def hideStdout(self):
-        if not self.stdoutHide:
-            self.stdoutHide = sys.stdout
-            self.stderrHide = sys.stderr
-            sys.stdout = StringIO()
-            sys.stderr = StringIO()
-            sys.stdout.fileno = self.stdoutHide.fileno
-            sys.stderr.fileno = self.stderrHide.fileno
-
-    def showStdout(self):
-        if self.stdoutHide:
-            sys.stdout = self.stdoutHide
-            sys.stderr = self.stderrHide
-            self.stdoutHide = None
-            self.stderrHide = None
-
-    def installDesktopClient(self):
-        """
-        Install desktop and client package
-        """
-        linuxShortname = self.clVars.Get('os_install_linux_shortname')
-        # install desktop package
-        if linuxShortname in ("CLD","CLS","CLDG","CLDX"):
-            generalLib = '/usr/lib/calculate-2.2/calculate-lib/pym'
-            desktopLib = '/usr/lib/calculate-2.2/calculate-desktop/pym'
-            if path.exists(generalLib) and path.exists(desktopLib):
-                sys.path.insert(0, path.abspath(generalLib))
-                sys.path.insert(0, path.abspath(desktopLib))
-                from cl_desktop import desktop
-                self.startTask(_("calculate-desktop enabled "
-                                 "for package configuration"))
-                self.hideStdout()
-                objDesktop = desktop()
-                objDesktop.createClVars()
-                if objDesktop.installProg():
-                    self.endTask()
-                else:
-                    self.printERROR()
-                self.showStdout()
-                sys.path.pop(0)
-                sys.path.pop(0)
-
-        # install client package
-        if linuxShortname in ("CLD","CLDG","CLDX"):
-            generalLib = '/usr/lib/calculate-2.2/calculate-lib/pym'
-            clientLib = '/usr/lib/calculate-2.2/calculate-client/pym'
-            if path.exists(generalLib) and path.exists(clientLib):
-                sys.path.insert(0, path.abspath(generalLib))
-                sys.path.insert(0, path.abspath(clientLib))
-                from cl_client import client
-                self.startTask(
-                 _("calculate-client enabled "
-                   "for package configuration"))
-                objClient = client()
-                objClient.createClVars()
-                self.hideStdout()
-                if hasattr(objClient,"updateEnvFiles") and \
-                    objClient.updateEnvFiles():
-                    objClient.clVars.flIniFile()
-                if objClient.installProg():
-                    self.endTask()
-                else:
-                    self.printERROR()
-                self.showStdout()
-                sys.path.pop(0)
-                sys.path.pop(0)
-
+    @safetyWrapper(native_errors=(MigrationError, TemplatesError, InstallError,
+                                  AutopartitionError, DistributiveError),
+                   man_int= __("Configuration manually interrupted"),
+                   post_action=closeClTemplate,
+                   success_message=__("System configured!"))
     def setupSystem(self,variables):
-        error = None
-        if variables:
-            self.clVars = variables
-        else:
-            self.initVars()
-        try:
-            target = None
-            setupType = self.clVars.Get('cl_setup',humanreadable=True)
+        self.initVars(variables)
+        target = None
+        setupType = self.clVars.Get('cl_setup',humanreadable=True)
 
-            if setupType:
-                self.startTask((_("%s are being configured")%
-                               setupType).capitalize(),progress=True)
-            else:
-                self.startTask(_("System configuration"),progress=True)
-            res = self.applyTemplatesStartup()
-            self.endTask()
-            if setupType and self.clVars.Get('cl_setup') == 'network':
-                pass
-            if not setupType or self.clVars.Get('cl_setup') == 'video':
-                self.setupVideo()
-            if setupType and self.clVars.Get('cl_setup') == 'users':
-                pass
-            if self.clVars.Get('cl_setup') == 'boot' and \
-                self.clVars.Get('os_root_type') != 'livecd':
-                target = self.clVars.Get('cl_image')
-                if self.clVars.Get('os_install_mbr'):
-                    self.startTask(_("Installing the bootloader"))
-                    self.prepareBoot(target)
+        if setupType:
+            self.startTask((_("%s are being configured")%
+                           setupType).capitalize(),progress=True)
+        else:
+            self.startTask(_("System configuration"),progress=True)
+        refreshLVM()
+        res = self.applyTemplatesStartup()
+        self.endTask()
+        if setupType and self.clVars.Get('cl_setup') == 'network':
+            pass
+        if not setupType or self.clVars.Get('cl_setup') == 'video':
+            self.setupVideo()
+        if setupType and self.clVars.Get('cl_setup') == 'users':
+            pass
+        if self.clVars.Get('cl_setup') == 'boot' and \
+            self.clVars.Get('os_root_type') != 'livecd':
+            target = self.clVars.Get('cl_image')
+            if self.clVars.Get('os_install_mbr'):
+                self.startTask(_("Installing the bootloader"))
+                self.prepareBoot(target)
+                self.endTask()
+            root_dev = self.clVars.Select('os_disk_parent',
+                                   where='os_disk_mount',
+                                   eq='/',limit=1)
+            if root_dev:
+                self.startTask(_("Changing the I/O scheduler"))
+                try:
+                    schedpath = ("/sys%s/queue/scheduler"%
+                      (getUdevDeviceInfo(name=root_dev).get('DEVPATH','')))
+                    if path.exists(schedpath):
+                        open(schedpath,'w').write(
+                            self.clVars.Get('os_install_kernel_scheduler'))
                     self.endTask()
-                root_dev = self.clVars.Select('os_disk_parent',
-                                       where='os_disk_mount',
-                                       eq='/',limit=1)
-                if root_dev:
-                    self.startTask(_("Changing the I/O scheduler"))
-                    try:
-                        schedpath = ("/sys%s/queue/scheduler"%
-                          (getUdevDeviceInfo(name=root_dev).get('DEVPATH','')))
-                        if path.exists(schedpath):
-                            open(schedpath,'w').write(
-                                self.clVars.Get('os_install_kernel_scheduler'))
-                        self.endTask()
-                    except:
-                        self.printERROR(_("Unable to change the I/O scheduler"))
-                        pass
-            if not setupType:
-                self.installDesktopClient()
-        except KeyboardInterrupt:
-            error = _("Configuration manually interrupted")
-            self.printERROR(error)
-        except (MigrationError,
-                TemplatesError,
-                InstallError,
-                AutopartitionError,
-                DistributiveError) as e:
-            error = str(e)
-            self.printERROR(error)
-        except (BaseException),e:
-            error = ""
-            for i in apply(traceback.format_exception, sys.exc_info()):
-                error += i
-            self.printERROR(error)
-            return False
-        finally:
-            try:
-                self.clVars.close()
-                if target:
-                    target.close()
-            except (MigrationError,
-                    TemplatesError,
-                    InstallError,
-                    AutopartitionError,
-                    DistributiveError) as e:
-                error = str(e)
-                self.printERROR(error)
-            except (BaseException),e:
-                error = ""
-                for i in apply(traceback.format_exception, sys.exc_info()):
-                    error += i
-                self.printERROR(error)
-                return False
-        if not error:
-            self.printSUCCESS(_("System configured")+"!")
-            self.endTask()
-            self.endFrame()
+                except:
+                    self.printERROR(_("Unable to change the I/O scheduler"))
+                    pass
         return True
 
+    def installPostAction(self,error):
+        """
+        Install post action
+        """
+        self.closeClTemplate()
+        if self.sourceDistr and self.sourceDistr.childs:
+            self.startTask(_("Letting go the source distribution"))
+            self.sourceDistr.close()
+            self.endTask()
+        if self.targetDistr and self.targetDistr.childs:
+            self.startTask(_("Unmounting the target system volume"))
+            self.targetDistr.close()
+            self.endTask()
+
+    @safetyWrapper(native_errors=(MigrationError, TemplatesError, InstallError,
+                                  AutopartitionError, DistributiveError),
+                   man_int= __("Installation manually interrupted"),
+                   post_action=installPostAction,
+                   failed_message=__("Failed to install the system!"),
+                   success_message=__("System successfully installed!"))
     def installSystem(self,variables):
         """install System by current variable enviroment"""
-        error = None
-        if variables:
-            self.clVars = variables
-        else:
-            self.initVars()
-        try:
-            results = []
-            self.writeFile()
-            # Помещение данных в словарь процессов
-            self.briefParams('install_view')
-            #self.beginFrame()
-            targetDistr = None
-            sourceDistr = None
-            try:
-                #self.clVars.printVars()
-                if self.clVars.Get('cl_autopartition_set') == 'on':
-                    self.startTask(_("Creating a new partition table"),
-                                   progress=True)
-                    ap = AutoPartition()
-                    devices = self.clVars.Get('cl_autopartition_device')
-                    ap.clearLvm(devices,self.clVars)
-                    ap.clearRaid(devices,self.clVars)
-                    ap.recreateSpace(
-                        self.clVars.Get('cl_autopartition_table'),
-                        devices,
-                        self.clVars.Get('cl_autopartition_disk_data'),
-                        self.clVars.GetBool('cl_autopartition_lvm_set'),
-                        self.clVars.Get('cl_autopartition_lvm_vgname'))
-                    self.endTask()
-                targetDistr = self.clVars.Get('cl_target')
-                sourceDistr = self.clVars.Get('cl_image')
-                self.setTaskNumber(25)
-                # cmd options
-                if targetDistr.needFormat:
-                    self.startTask(_("Formatting the partitions"),progress=True)
-                    targetDistr.performFormat()
-                    self.endTask()
-                # install distributive
-                #raise InstallError("Manual stop")
-                self.startTask(_("Unpacking the system image to the target"),
-                               progress=True,num=18)
-                self.clVars.Get('os_grub_conf')
-                # set spinner flag
-                filesnum = self.clVars.Get('os_install_linux_files')
-                if filesnum.isdigit():
-                    filesnum = int(filesnum)
-                else:
-                    filesnum = 0
-                targetDistr.installFrom(sourceDistr,
-                    callbackProgress=self.setProgress,
-                    filesnum=filesnum)
-                if self.clVars.Get('os_install_pxe') == 'off':
-                    targetDistr.convertToDirectory()
-                self.endTask()
-
-                self.clVars.processRefresh()
-                if self.clVars.Get('os_install_root_type') != "flash" and \
-                    self.clVars.Get('os_install_pxe') == 'off':
-                    self.afterCopyHDDinstall(targetDistr)
-                else:
-                    # join templates
-                    if self.clVars.Get('os_install_pxe') == 'on':
-                        self.startTask(
-                            _("Configuring the PXE install"),progress=True)
-                        self.applyTemplatesFlash('/')
-                    else:
-                        self.startTask(
-                            _("Configuring the Flash install"),progress=True)
-                        self.applyTemplatesFlash(targetDistr.getDirectory())
-                    self.endTask()
-                    self.closeClTemplate()
-                # change boot config
-                if self.clVars.Get('os_install_mbr') and \
-                    self.clVars.Get('os_install_pxe') == "off":
-                    self.startTask(_("Preparing the system for reboot"))
-                    self.prepareBoot(targetDistr)
-                self.endTask()
-            except EOFError as e:
-                error = str(e)
-            except (MigrationError,
-                    TemplatesError,
-                    InstallError,
-                    AutopartitionError,
-                    DistributiveError) as e:
-                error = str(e)
-            except Exception as e:
-                error = ""
-                for i in apply(traceback.format_exception, sys.exc_info()):
-                    error += i
-            except KeyboardInterrupt,e:
-                self.printWARNING(_("Installation interrupted"))
-                error = _("Installation manually interrupted")
-            if error:
-                self.printERROR(error)
-            try:
-                self.closeClTemplate()
-                if sourceDistr and sourceDistr.childs:
-                    self.startTask(_("Letting go the source distribution"))
-                    sourceDistr.close()
-                    self.endTask()
-                if targetDistr and targetDistr.childs:
-                    self.startTask(_("Unmounting the target system volume"))
-                    targetDistr.close()
-                    self.endTask()
-            except (VariableError,TemplatesError,
-                    InstallError,DistributiveError),e:
-                error = "%s\n%s" % (str(error),_("Unmounting error"))
-                self.printERROR(error)
-            except KeyboardInterrupt,e:
-                pass
-            if error:
-                self.printERROR(_("Failed to install the system")+"!")
-                return False
-            self.printSUCCESS(_("System successfully installed")+"!")
+        self.initVars(variables)
+        results = []
+        #self.beginFrame()
+        self.targetDistr = None
+        self.sourceDistr = None
+        #self.clVars.printVars()
+        self.setTaskNumber(25)
+        if self.clVars.Get('cl_autopartition_set') == 'on':
+            self.startTask(_("Creating a new partition table"),
+                           progress=True)
+            ap = AutoPartition()
+            devices = self.clVars.Get('cl_autopartition_device')
+            ap.clearLvm(devices,self.clVars)
+            ap.clearRaid(devices,self.clVars)
+            ap.recreateSpace(
+                self.clVars.Get('cl_autopartition_table'),
+                devices,
+                self.clVars.Get('cl_autopartition_disk_data'),
+                self.clVars.GetBool('cl_autopartition_lvm_set'),
+                self.clVars.Get('cl_autopartition_lvm_vgname'))
             self.endTask()
-            self.endFrame()
-            # necessary for correct complete the process
-            return True
-        except (BaseException),e:
-            error = ""
-            for i in apply(traceback.format_exception, sys.exc_info()):
-                error += i
-            self.printERROR(error)
-            return False
-        finally:
-            try:
-                self.clVars.close()
-            except (BaseException),e:
-                error = ""
-                for i in apply(traceback.format_exception, sys.exc_info()):
-                    error += i
-                self.printERROR(error)
-                return False
+        self.targetDistr = self.clVars.Get('cl_target')
+        self.sourceDistr = self.clVars.Get('cl_image')
+        # cmd options
+        if self.targetDistr.needFormat:
+            self.startTask(_("Formatting the partitions"),progress=True)
+            self.targetDistr.performFormat()
+            self.endTask()
+        # install distributive
+        #raise InstallError("Manual stop")
+        self.startTask(_("Unpacking the system image to the target"),
+                       progress=True,num=18)
+        self.clVars.Get('os_grub_conf')
+        # set spinner flag
+        filesnum = self.clVars.Get('os_install_linux_files')
+        if filesnum.isdigit():
+            filesnum = int(filesnum)
+        else:
+            filesnum = 0
+        self.targetDistr.installFrom(self.sourceDistr,
+            callbackProgress=self.setProgress,
+            filesnum=filesnum)
+        if self.clVars.Get('os_install_pxe') == 'off':
+            self.targetDistr.convertToDirectory()
+        self.endTask()
+
+        self.clVars.processRefresh()
+        if self.clVars.Get('os_install_root_type') != "flash" and \
+            self.clVars.Get('os_install_pxe') == 'off':
+            self.afterCopyHDDinstall(self.targetDistr)
+        else:
+            # join templates
+            if self.clVars.Get('os_install_pxe') == 'on':
+                self.startTask(
+                    _("Configuring PXE install"),progress=True)
+                self.applyTemplatesFlash('/')
+            else:
+                self.startTask(
+                    _("Configuring Flash install"),progress=True)
+                self.applyTemplatesFlash(self.targetDistr.getDirectory())
+            self.endTask()
+            self.closeClTemplate()
+        # change boot config
+        if self.clVars.Get('os_install_mbr') and \
+            self.clVars.Get('os_install_pxe') == "off":
+            self.startTask(_("Preparing the system for reboot"))
+            self.prepareBoot(self.targetDistr)
+        self.endTask()
         return True
+
+    def rndString(self):
+        """Get random string with len 8 char"""
+        return "".join([choice(string.ascii_letters+string.digits)
+                    for i in xrange(0,8)])
+
+    def _getFreeDirectory(self,directory):
+        """
+        Get free directory name
+        """
+        newDirectoryName = directory
+        while path.exists(newDirectoryName):
+            newDirectoryName = "%s.%s"%(directory,self.rndString())
+        return newDirectoryName
+
+    def remountNTFS(self):
+        """
+        Remount NTFS partitions 
+        """
+        for disk in self.clVars.Select('os_disk_dev',
+                                where='os_disk_format',like='ntfs'):
+            mountDir = self._getFreeDirectory('/var/lib/calculate/mount.ntfs')
+            try:
+                os.mkdir(mountDir)
+            except:
+                continue
+            if process('/bin/mount',disk,mountDir).success():
+                for i in (0.2,0.5,1,2,4,5):
+                    if process('/bin/umount',mountDir).success():
+                        break
+                else:
+                    self.printWARNING(_("Unable to umount %s")%mountDir)
+            try:
+                os.rmdir(mountDir)
+            except:
+                self.printWARNING(_("Unable to remove directory %s")%mountDir)
