@@ -30,6 +30,7 @@ from calculate.install.cl_install import InstallError
 import cl_install
 from calculate.lib.cl_lang import setLocalTranslate,getLazyLocalTranslate
 from calculate.core.server.decorators import Dec
+from calculate.core.server.func import catchExcept,commonView
 core_method = Dec.core_method
 setLocalTranslate('cl_install3',sys.modules[__name__])
 import traceback
@@ -87,80 +88,13 @@ class InstallInfo(ClassSerializer):
     CheckOnly = Boolean
     CheckAll = Boolean
 
-class catchExcept:
-    def __init__(self,f):
-        self.f = f
-        self.func_name = f.func_name
-        self.func_code = f.func_code
-        self.__doc__ = f.__doc__
-        self.__name__ = f.__name__
-    
-    def __call__(self,*args,**kwargs):
-        try:
-            return self.f(*args,**kwargs)
-        except BaseException as e:
-            view = ViewInfo(groups=[])
-            group = GroupField(name=_("Error"),last=True)
-            group.fields = []
-            group.fields.append(Field(
-                    name = "error",
-                    label = str(e),
-                    default = 'color:red;',
-                    element = "error"))
-            view.groups.append(group)
-            if not type(e) in (InstallError,DataVarsError,VariableError):
-                for i in apply(traceback.format_exception, sys.exc_info()):
-                    print i,
-
-            return view
+installCatchExcept = catchExcept(VariableError,DataVarsError,
+                                 cl_install.InstallError)
 
 class Wsdl:
     from calculate.core.server.baseClass import Basic
     from calculate.core.server.decorators import Dec
 
-    def installCommon(self,sid,info,methodname,initfunc,
-                      installFunc="installSystem"):
-        """
-        Install common method
-        """
-        try:
-            dv = self.get_cache(sid,methodname,"vars")
-            if not dv:
-                dv = initfunc()
-            else:
-                if methodname == "install":
-                    self.fixInstallLocalization(sid,dv)
-                dv.processRefresh()
-            if info:
-                checkonly = info.CheckOnly
-                checkall = info.CheckAll
-            else:
-                checkonly = False
-                checkall = False
-            errors = map(lambda x:ReturnedMessage(**x),
-                     dv.checkGroups(info,allvars=checkall or \
-                                         not checkonly))
-            if errors:
-                return errors
-            if checkonly:
-                returnmess = ReturnedMessage(type = '', message = None)
-                return [returnmess]
-            install_meth = type("CommonInstall",(self.Common,
-                                cl_install.Install, object), {})
-            pid = self.startprocess(sid, target=install_meth,
-                            method=installFunc,\
-                            method_name=methodname or "install",
-                            args_proc = (dv,))
-            returnmess = ReturnedMessage(type = 'pid', message = pid)
-            returnmess.type = "pid"
-            returnmess.message = pid
-            dv = self.clear_cache(sid,methodname)
-            return [returnmess]
-        finally:
-            if dv:
-                self.set_cache(sid,methodname,"vars",dv,smart=False)
-        return []
-
     @rpc(Integer, InstallInfo, _returns = Array(ReturnedMessage))
     @core_method(category=__('Installation'),title=__("System install"),
         image='calculate-install,system-installer,applications-other,'
@@ -168,7 +102,9 @@ class Wsdl:
         gui=True,command='cl-install',
         rights=['install'])
     def install ( self, sid, info):
-        return self.installCommon(sid,info,'install',self.install_vars)
+        return self.callMethod(sid,info,logicClass=cl_install.Install,
+                               method="installSystem",method_name="install",
+                               callbackRefresh=self.fixInstallLocalization)
 
     def install_vars(self,dv=None):
         if not dv:
@@ -224,7 +160,7 @@ class Wsdl:
             return False
 
     @rpc(Integer, ViewParams, _returns = ViewInfo)
-    @catchExcept
+    @installCatchExcept
     def install_view (self, sid, params):
         dv = self.get_cache(sid,"install","vars")
         if not dv:
@@ -236,12 +172,10 @@ class Wsdl:
             self.set_cache(sid,"install","lang",lang,smart=False)
             dv.processRefresh()
         self.set_cache(sid, 'install', "vars",dv,smart=False)
-        view = ViewInfo(dv,step=params.step,
-                           expert=params.expert,
-                           brief=params.brief,
-                           has_brief=True,
-                           allsteps=langChanged,
-                           brief_label=_("Start installing"))
+        view = ViewInfo(dv,viewparams=params,
+                        has_brief=True,
+                        allsteps=langChanged,
+                        brief_label=_("Start installing"))
         return view
 
     def install_flash_vars(self):
@@ -258,28 +192,20 @@ class Wsdl:
 
     @rpc(Integer, InstallInfo, _returns = Array(ReturnedMessage))
     @core_method(category=__('Installation'),title=__('Flash install'),
-        image='drive-removable-media-usb-pendrive,media-flash',
+        image='drive-removable-media-usb-pendrive,'
+              'drive-removable-media-usb,media-flash',
         gui=True, rights=['install'])
     def install_flash ( self, sid, info):
         """
         Install to flash
         """
-        return self.installCommon(sid,info,'install_flash',
-                                  self.install_flash_vars)
+        return self.callMethod(sid,info,logicClass=cl_install.Install,
+                           method="installSystem",method_name="install_flash")
 
     @rpc(Integer, ViewParams,_returns = ViewInfo)
-    @catchExcept
+    @installCatchExcept
     def install_flash_view (self, sid, params):
-        dv = self.get_cache(sid,"install_flash","vars")
-        if not dv:
-            dv = self.install_flash_vars()
-        else:
-            dv.processRefresh()
-        self.set_cache(sid, 'install_flash', "vars",dv,smart=False)
-        view = ViewInfo(dv,step=params.step,
-                           expert=params.expert,
-                           brief=params.brief)
-        return view
+        return commonView(self,sid,params,"install_flash")
 
     def install_pxe_vars(self):
         dv = cl_install.DataVarsInstall()
@@ -295,28 +221,20 @@ class Wsdl:
 
     @rpc(Integer, InstallInfo, _returns = Array(ReturnedMessage))
     @core_method(category=__('Installation'),title=__('PXE install'),
-        image='network-server',command='cl-install-pxe',
+        image='network-server,preferences-desktop-remote-desktop',
+        command='cl-install-pxe',
         gui=True, rights=['installpxe'])
     def install_pxe ( self, sid, info):
         """
         Install to flash
         """
-        return self.installCommon(sid,info,'install_pxe',
-                                  self.install_pxe_vars)
+        return self.callMethod(sid,info,logicClass=cl_install.Install,
+                           method="installSystem",method_name="install_pxe")
 
     @rpc(Integer, ViewParams,_returns = ViewInfo)
-    @catchExcept
+    @installCatchExcept
     def install_pxe_view (self, sid, params):
-        dv = self.get_cache(sid,"install_pxe","vars")
-        if not dv:
-            dv = self.install_pxe_vars()
-        else:
-            dv.processRefresh()
-        self.set_cache(sid, 'install_pxe', "vars",dv,smart=False)
-        view = ViewInfo(dv,step=params.step,
-                           expert=params.expert,
-                           brief=params.brief)
-        return view
+        return commonView(self,sid,params,"install_pxe")
 
     def setup_network_vars(self):
         dv = cl_install.DataVarsInstall()
@@ -335,30 +253,21 @@ class Wsdl:
 
     @rpc(Integer, InstallInfo, _returns = Array(ReturnedMessage))
     @core_method(category=__('Configuration'),title=__('Network'),
-        image='network-idle,preferences-system-network',
+        image='gnome-network-properties,'
+              'network-idle,preferences-system-network',
         command="cl-setup-network",
         gui=True, rights=['setup'])
     def setup_network ( self, sid, info):
         """
         Setup network
         """
-        return self.installCommon(sid,info,'setup_network',
-                                  self.setup_network_vars,
-                                  installFunc="setupSystem")
+        return self.callMethod(sid,info,logicClass=cl_install.Install,
+                           method="setupSystem",method_name="setup_network")
 
     @rpc(Integer, ViewParams,_returns = ViewInfo)
-    @catchExcept
+    @installCatchExcept
     def setup_network_view (self, sid, params):
-        dv = self.get_cache(sid,"setup_network","vars")
-        if not dv:
-            dv = self.setup_network_vars()
-        else:
-            dv.processRefresh()
-        self.set_cache(sid, 'setup_network', "vars",dv,smart=False)
-        view = ViewInfo(dv,step=params.step,
-                           expert=params.expert,
-                           brief=params.brief)
-        return view
+        return commonView(self,sid,params,"setup_network")
 
     def setup_video_vars(self):
         dv = cl_install.DataVarsInstall()
@@ -375,30 +284,20 @@ class Wsdl:
 
     @rpc(Integer, InstallInfo, _returns = Array(ReturnedMessage))
     @core_method(category=__('Configuration'),title=__('Video'),
-        image='gnome-multimedia,video-display',
+        image='video-display,gnome-multimedia',
         command="cl-setup-video",
         gui=True, rights=['setup'])
     def setup_video ( self, sid, info):
         """
         Setup video
         """
-        return self.installCommon(sid,info,'setup_video',
-                                  self.setup_video_vars,
-                                  installFunc="setupSystem")
+        return self.callMethod(sid,info,logicClass=cl_install.Install,
+                           method="setupSystem",method_name="setup_video")
 
     @rpc(Integer, ViewParams,_returns = ViewInfo)
-    @catchExcept
+    @installCatchExcept
     def setup_video_view (self, sid, params):
-        dv = self.get_cache(sid,"setup_video","vars")
-        if not dv:
-            dv = self.setup_video_vars()
-        else:
-            dv.processRefresh()
-        self.set_cache(sid, 'setup_video', "vars",dv,smart=False)
-        view = ViewInfo(dv,step=params.step,
-                           expert=params.expert,
-                           brief=params.brief)
-        return view
+        return commonView(self,sid,params,"setup_video")
 
     def setup_locale_vars(self):
         dv = cl_install.DataVarsInstall()
@@ -422,23 +321,13 @@ class Wsdl:
         """
         Setup locale
         """
-        return self.installCommon(sid,info,'setup_locale',
-                                  self.setup_locale_vars,
-                                  installFunc="setupSystem")
+        return self.callMethod(sid,info,logicClass=cl_install.Install,
+                           method="setupSystem",method_name="setup_locale")
 
     @rpc(Integer, ViewParams,_returns = ViewInfo)
-    @catchExcept
+    @installCatchExcept
     def setup_locale_view (self, sid, params):
-        dv = self.get_cache(sid,"setup_locale","vars")
-        if not dv:
-            dv = self.setup_locale_vars()
-        else:
-            dv.processRefresh()
-        self.set_cache(sid, 'setup_locale', "vars",dv,smart=False)
-        view = ViewInfo(dv,step=params.step,
-                           expert=params.expert,
-                           brief=params.brief)
-        return view
+        return commonView(self,sid,params,"setup_locale")
 
     def setup_boot_vars(self):
         dv = cl_install.DataVarsInstall()
@@ -461,29 +350,20 @@ class Wsdl:
         """
         Setup locale
         """
-        return self.installCommon(sid,info,'setup_boot',
-                                  self.setup_boot_vars,
-                                  installFunc="setupSystem")
+        return self.callMethod(sid,info,logicClass=cl_install.Install,
+                           method="setupSystem",method_name="setup_boot")
 
     @rpc(Integer, ViewParams,_returns = ViewInfo)
-    @catchExcept
+    @installCatchExcept
     def setup_boot_view (self, sid, params):
-        dv = self.get_cache(sid,"setup_boot","vars")
-        if not dv:
-            dv = self.setup_boot_vars()
-        else:
-            dv.processRefresh()
-        self.set_cache(sid, 'setup_boot', "vars",dv,smart=False)
-        view = ViewInfo(dv,step=params.step,
-                           expert=params.expert,
-                           brief=params.brief)
-        return view
+        return commonView(self,sid,params,"setup_boot")
 
     def setup_system_vars(self):
         dv = cl_install.DataVarsInstall()
         dv.importInstall()
         dv.flIniFile()
         dv.Set('cl_action','merge',True)
+        dv.Set('cl_live','off')
         dv.addGroup(None,
             normal=("cl_live",),
             expert=('cl_templates_locate',),
@@ -492,26 +372,16 @@ class Wsdl:
 
     @rpc(Integer, InstallInfo, _returns = Array(ReturnedMessage))
     @core_method(category=__('Configuration'),title=__('System'),
-        image='system,computer',command="cl-setup-system",
+        image='system-run,system,computer',command="cl-setup-system",
         gui=True, rights=['setup'])
     def setup_system ( self, sid, info):
         """
         Setup system
         """
-        return self.installCommon(sid,info,'setup_system',
-                                  self.setup_system_vars,
-                                  installFunc="setupSystem")
+        return self.callMethod(sid,info,logicClass=cl_install.Install,
+                           method="setupSystem",method_name="setup_system")
 
     @rpc(Integer, ViewParams,_returns = ViewInfo)
-    @catchExcept
+    @installCatchExcept
     def setup_system_view (self, sid, params):
-        dv = self.get_cache(sid,"setup_system","vars")
-        if not dv:
-            dv = self.setup_system_vars()
-        else:
-            dv.processRefresh()
-        self.set_cache(sid, 'setup_system', "vars",dv,smart=False)
-        view = ViewInfo(dv,step=params.step,
-                           expert=params.expert,
-                           brief=params.brief)
-        return view
+        return commonView(self,sid,params,"setup_system")
