@@ -44,7 +44,7 @@ class NetHelper:
         """
         if self.Get('os_install_root_type') == 'flash':
             return \
-                _("Network configuration is unavailable for the Flash install")
+                _("Network configuration is unavailable for Flash install")
         if self.routing and not self.Select('os_install_net_interfaces',
                        where='os_install_net_dhcp_set',
                        eq='off',limit=1):
@@ -120,7 +120,7 @@ class VariableOsInstallNetData(NetHelper,TableVariable):
         self.label = _("Addresses")
 #        self.help = _("IP address with network (example:%s)")%"192.168.1.1/24"
         self.help = _("Network interface, DHCP, IP address and network mask "
-                      "(example:%s)")%" --ip eth0:off:192.168.1.1:24"
+                      "(example: %s)")%" --ip eth0:off:192.168.1.1:24"
 
 class VariableOsInstallNetHostname(NetHelper,Variable):
     """
@@ -347,6 +347,9 @@ class VariableOsInstallNetRouteData(NetHelper,TableVariable):
               'os_install_net_route_src']
     routing = True
 
+    def humanReadable(self):
+        return self.Get()
+
     def init(self):
         self.label = _("Routing")
         self.help = \
@@ -470,7 +473,7 @@ class VariableOsInstallNetRouteSrc(FieldValue,NetHelper,Variable):
     column = 3
 
     def init(self):
-        self.label = _("Source")
+        self.label = _("Source IP")
 
     def choice(self):
         return [""]+self.Get('os_install_net_ip')
@@ -663,7 +666,7 @@ class VariableOsInstallNetDns(VariableOsInstallNetDnsSearch):
     def check(self,value):
         reIp = re.compile(ip.IP_ADDR)
         if any(ifilterfalse(reIp.match,value.split(','))):
-            raise VariableError(_("Wrong IP addresses for DNS"))
+            raise VariableError(_("Wrong IP address for DNS"))
 
     def humanReadable(self):
         return self.Get() or (_("Get via DHCP") 
@@ -674,4 +677,8 @@ class VariableOsInstallNetSettings(NetHelper,Variable):
     """
     Net service configured
     """
+    type = "choice"
     value = ""
+
+    def choice(self):
+        return [("","")]+self.Get('os_install_net_conf_available')
